sqltriples.Query.IntersectionOfTuples

Package sqltriples :: Module Query :: Class IntersectionOfTuples |
[show private | hide private]
[frames | no frames]

## Class IntersectionOfTuples

        CombinedResults --+
                          |
    CombinedTopLevelResults --+
                              |
                   Intersection --+
                                  |
      AbstractQuery --+           |
                      |           |
                  Query --+       |
                          |       |
                    Results --+   |
                              |   |
                         Tuples --+
                                  |
                                 IntersectionOfTuples

Method Summary
| `__init__(self, store, queries, pattern)`
Inherited from CombinedTopLevelResults
| ``get_query`(self, index)`
| ``get_subquery`(self, parent_columns, parent_index, index, match_first, match_parent, match_child)`
Inherited from Query
| ``__getitem__`(self, i)`
| ``__len__`(self)`
| ``__repr__`(self)`

Class Variable Summary
Inherited from Intersection
`int` | `in_parentheses` = 0
`str` | `operator` = `'intersect'`
Inherited from Tuples
`list` | `exposed_columns` = `[('subject', 'subject_type'), ('predic...`
Inherited from AbstractQuery
`list` | `table_columns` = `[('subject', 'subject_type', 0), ('predi...`

Generated by Epydoc 2.1 on Fri Jan 12 00:04:34 2007 | http://epydoc.sf.net